#
# spec file for package flite
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           flite
Version:        2.2
Release:        1.8
Summary:        Small, fast speech synthesis engine (text-to-speech)
License:        BSD-3-Clause-Modification
Group:          Productivity/Multimedia/Other
URL:            https://github.com/festvox/flite
Source:         https://github.com/festvox/flite/archive/refs/tags/v%{version}.tar.gz
Patch0:         flite-2.2-lto.patch
Patch1:         flite-2.2-texinfo-7.0.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  ed
BuildRequires:  libpulse-devel
BuildRequires:  libtool
BuildRequires:  texi2html
BuildRequires:  texinfo

%description
Flite (festival-lite) is a small, fast run-time speech synthesis engine
developed at CMU and primarily designed for small embedded machines and/or
large servers. Flite is designed as an alternative synthesis engine to
Festival for voices built using the FestVox suite of voice building tools.

%package -n libflite1
Summary:        Small, fast speech synthesis engine (libraries)
Group:          System/Libraries

%description -n libflite1

%package -n libflite_cmu_grapheme_lang1
Summary:        Small, fast speech synthesis engine (libraries)
Group:          System/Libraries

%description -n libflite_cmu_grapheme_lang1

%package -n libflite_cmu_grapheme_lex1
Summary:        Small, fast speech synthesis engine (libraries)
Group:          System/Libraries

%description -n libflite_cmu_grapheme_lex1

%package -n libflite_cmu_indic_lang1
Summary:        Small, fast speech synthesis engine (libraries)
Group:          System/Libraries

%description -n libflite_cmu_indic_lang1

%package -n libflite_cmu_indic_lex1
Summary:        Small, fast speech synthesis engine (libraries)
Group:          System/Libraries

%description -n libflite_cmu_indic_lex1

%package -n libflite_cmu_time_awb1
Summary:        Small, fast speech synthesis engine (libraries)
Group:          System/Libraries

%description -n libflite_cmu_time_awb1

%package -n libflite_cmu_us_awb1
Summary:        Small, fast speech synthesis engine (libraries)
Group:          System/Libraries

%description -n libflite_cmu_us_awb1

%package -n libflite_cmu_us_kal1
Summary:        Small, fast speech synthesis engine (libraries)
Group:          System/Libraries

%description -n libflite_cmu_us_kal1

%package -n libflite_cmu_us_kal16-1
Summary:        Small, fast speech synthesis engine (libraries)
Group:          System/Libraries

%description -n libflite_cmu_us_kal16-1

%package -n libflite_cmu_us_rms1
Summary:        Small, fast speech synthesis engine (libraries)
Group:          System/Libraries

%description -n libflite_cmu_us_rms1

%package -n libflite_cmu_us_slt1
Summary:        Small, fast speech synthesis engine (libraries)
Group:          System/Libraries

%description -n libflite_cmu_us_slt1

%package -n libflite_cmulex1
Summary:        Small, fast speech synthesis engine (libraries)
Group:          System/Libraries

%description -n libflite_cmulex1

%package -n libflite_usenglish1
Summary:        Small, fast speech synthesis engine (libraries)
Group:          System/Libraries

%description -n libflite_usenglish1

%package devel
Summary:        Development files for flite
Group:          Development/Libraries/C and C++
Requires:       flite = %{version}

%description devel
Development files for Flite, a small, fast speech synthesis engine.

%prep
%autosetup -p1

%build
autoreconf -vif
%configure \
    --enable-shared \
    --disable-static \
    --with-audio=pulseaudio

# This package fails to build with parallel make
%make_build -j1
# Build documentation
cd doc
%make_build flite.html

%install
make install INSTALLBINDIR="%{buildroot}/%{_bindir}" \
	INSTALLLIBDIR="%{buildroot}/%{_libdir}" \
	INSTALLINCDIR="%{buildroot}/%{_includedir}/flite"
rm -f "%{buildroot}/%{_libdir}"/*.a

%post   -n libflite1 -p /sbin/ldconfig
%postun -n libflite1 -p /sbin/ldconfig
%post   -n libflite_cmu_grapheme_lang1 -p /sbin/ldconfig
%postun -n libflite_cmu_grapheme_lang1 -p /sbin/ldconfig
%post   -n libflite_cmu_grapheme_lex1 -p /sbin/ldconfig
%postun -n libflite_cmu_grapheme_lex1 -p /sbin/ldconfig
%post   -n libflite_cmu_indic_lang1 -p /sbin/ldconfig
%postun -n libflite_cmu_indic_lang1 -p /sbin/ldconfig
%post   -n libflite_cmu_indic_lex1 -p /sbin/ldconfig
%postun -n libflite_cmu_indic_lex1 -p /sbin/ldconfig
%post   -n libflite_cmu_time_awb1 -p /sbin/ldconfig
%postun -n libflite_cmu_time_awb1 -p /sbin/ldconfig
%post   -n libflite_cmu_us_awb1 -p /sbin/ldconfig
%postun -n libflite_cmu_us_awb1 -p /sbin/ldconfig
%post   -n libflite_cmu_us_kal1 -p /sbin/ldconfig
%postun -n libflite_cmu_us_kal1 -p /sbin/ldconfig
%post   -n libflite_cmu_us_kal16-1 -p /sbin/ldconfig
%postun -n libflite_cmu_us_kal16-1 -p /sbin/ldconfig
%post   -n libflite_cmu_us_rms1 -p /sbin/ldconfig
%postun -n libflite_cmu_us_rms1 -p /sbin/ldconfig
%post   -n libflite_cmu_us_slt1 -p /sbin/ldconfig
%postun -n libflite_cmu_us_slt1 -p /sbin/ldconfig
%post   -n libflite_cmulex1 -p /sbin/ldconfig
%postun -n libflite_cmulex1 -p /sbin/ldconfig
%post   -n libflite_usenglish1 -p /sbin/ldconfig
%postun -n libflite_usenglish1 -p /sbin/ldconfig

%files
%{_bindir}/*

%files -n libflite1
%{_libdir}/libflite.so.*

%files -n libflite_cmu_grapheme_lang1
%{_libdir}/libflite_cmu_grapheme_lang.so.*

%files -n libflite_cmu_grapheme_lex1
%{_libdir}/libflite_cmu_grapheme_lex.so.*

%files -n libflite_cmu_indic_lang1
%{_libdir}/libflite_cmu_indic_lang.so.*

%files -n libflite_cmu_indic_lex1
%{_libdir}/libflite_cmu_indic_lex.so.*

%files -n libflite_cmu_time_awb1
%{_libdir}/libflite_cmu_time_awb.so.*

%files -n libflite_cmu_us_awb1
%{_libdir}/libflite_cmu_us_awb.so.*

%files -n libflite_cmu_us_kal1
%{_libdir}/libflite_cmu_us_kal.so.*

%files -n libflite_cmu_us_kal16-1
%{_libdir}/libflite_cmu_us_kal16.so.*

%files -n libflite_cmu_us_rms1
%{_libdir}/libflite_cmu_us_rms.so.*

%files -n libflite_cmu_us_slt1
%{_libdir}/libflite_cmu_us_slt.so.*

%files -n libflite_cmulex1
%{_libdir}/libflite_cmulex.so.*

%files -n libflite_usenglish1
%{_libdir}/libflite_usenglish.so.*

%files devel
%{_includedir}/flite/
%{_libdir}/*.so
%license COPYING
%doc ACKNOWLEDGEMENTS README.md doc/html

%changelog
* Sat Sep 16 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2:
  * Better grapheme support for hundreds of new languages
    as part of Wilderness project
  * Also includes updated G2P rules for indic
- add flite-2.2-lto.patch (build with LTO)
- add flite-2.2-texinfo-7.0.patch (build with newer texinfo)
* Sun Jan 17 2016 jengelh@inai.de
- Update to new upstream release 2.0.0
  * No changelog provided
* Tue Apr  7 2015 vodoo@vakw.ch
- add patch for doc/Makefile, changed option -number to -number-sections
  to avoid option error
* Thu Mar 26 2015 adrian@suse.de
- fix build for factory, adding texi2html build requires
* Mon Dec 26 2011 jengelh@medozas.de
- Remove redundant sections
* Thu Dec 15 2011 chris@computersalat.de
- rework shlibs patch
  * add -lm ti linker flags
- fix deps
  * BuildReq: autoconf
- spec-cleanup
- fix changes file
* Sun Mar 14 2010 chris@computersalat.de
- update to version 1.4
  o crude multi-voice selection support (may change)
  o 4 basic voices are included 3 clustergen (awb, rms and slt)
    plus the kal diphone database
  o CMULEX now uses maximum onset for syllabification
  o alsa support
  o Clustergen support (including mlpg with mixed excitation)
    But is still slow on limited processors
  o Windows support with Visual Studio (specifically for the
    Olympus Spoken Dialog System)
  o WinCE support is redone with cegcc/mingw32ce with example
    example TTS app: Fluwm: Flite on Windows Mobile
  o Speed-ups in feature interpretation limiting calls to alloc
  o Speed-ups (and fixes) for converting clunits festvox voices
- removed obsolete sources/patches
  o README-ALSA.txt
  o flite-1.3-alsa_support.patch
- reworked patches
  o flite-1.3-sharedlibs.patch > flite-1.4-sharedlibs.patch
- cleanup spec
  o added header
  o sort TAGS
  o bzipped Source
  o macros
- changelog to changes file
* Tue Nov 14 2006 faucamp@csir.co.za
- Added comment to %%%%build stating why "_smp_flags" isn't used with make
* Mon Nov 13 2006 faucamp@csir.co.za
- Modified alsa support patch file to patch "configure.in" instead of "configure"
- Added "autoconf" step to %%%%build
- Added BuildRequires: autoconf
- Fixed patch backup file suffixes
- Renamed patch files to a more standard format
- Moved header files from /usr/include to /usr/include/flite
- Added -p option to all cp operations (to preserve timestamps)
* Sun Nov 12 2006 faucamp@csir.co.za
- Recreated patch to allow shared libraries to build correctly (sharedlibs.patch)
- "flite" and "flite_time" binaries now link to flite shared libraries (sharedlibs.patch)
- Simplified the documentation patch filename
- Modified patch steps in %%%%prep to create backup files with different suffixes
- Removed "_smp_flags" macro from %%%%build for all archs
* Fri Oct 20 2006 faucamp@csir.co.za
- Modified "build" so that "_smp_flags" is only used for i386 arch
* Tue Oct 10 2006 faucamp@csir.co.za
- Removed "_smp_flags" macro from "build" for x86_64 arch
* Tue Sep 26 2006 faucamp@csir.co.za
- Added README-ALSA.txt (Source1)
- Removed subpackage: flite-devel-static
- Modified shared libraries patch (Patch0) to prevent building static libraries
- Renamed patch files: Patch0, Patch1
- Added flite 1.3 ALSA patch (Patch2) by Lukas Loehrer - thanks Anthony Green for pointing it out
- Added configure option: --with-audio=alsa
- Added BuildRequires: alsa-lib-devel
* Fri Sep 22 2006 faucamp@csir.co.za
- Initial RPM build
